/*
 * =======================================================================
 * ============================ JAR WIZARD ===============================
 * =======================================================================
 *
 *                                                 Copyright (C) 2002 Chir
 *
 * DESCRIPTION:   This Swing program helps packing a Java application
 *                into a JAR file that then launches with 2 clicks.
 *
 * THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
 * THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
 * (AT YOUR OPTION) ANY LATER VERSION.
 */

import org.chir.*;
import org.chir.swing.*;
import java.io.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.datatransfer.*;
import javax.swing.*;
import java.net.*;
import java.util.*;

/**
 * Mainframe for the JarWizard application.
 *
 * @author  Chir
 */
public class JarWizard extends javax.swing.JFrame
{
    public static void main( String args[] )
    {
        try
        {
            System.setSecurityManager( null );  // Turn off the sandbox (if signed).
            Toolkit.getDefaultToolkit().setDynamicLayout(true);
            JFrame.setDefaultLookAndFeelDecorated( true );
            JDialog.setDefaultLookAndFeelDecorated( true );
//          UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());    // Native L&F
        }
        catch(Exception e)  { /* Do nothing */ }
        new JarWizard().setVisible(true);
    }

    /** Creates a new JarWizard main frame */
    public JarWizard()
    {
        super( "JAR Creation Wizard v" + VERSION_T + "  by Chir" );

        setIconImage( LoadImage.LoadImage( getClass(), "gui/icon.gif" ) );
        setResizable( false );

        initComponents();
        int k = 0;
        for( JarType t : JarType.values() )  { tau.put(k++,t); }
        for( Map.Entry<Integer,JarType> e : tau.entrySet() )  antitau.put( e.getValue(), e.getKey() );

        JLabel[] listData = new JLabel[antitau.size()];
        listData[ antitau.get(JarType.APPLET_JAR) ] = new JLabel( "Applet", new ImageIcon(getClass().getResource("gui/applet.gif")), SwingConstants.LEFT );
        listData[ antitau.get(JarType.APPLIC_JAR) ] = new JLabel( "Application", new ImageIcon(getClass().getResource("gui/application.gif")), SwingConstants.LEFT );
        listData[ antitau.get(JarType.CONSOLE_JAR) ] = new JLabel( "Console application", new ImageIcon(getClass().getResource("gui/console.gif")), SwingConstants.LEFT );
        listData[ antitau.get(JarType.BEAN_JAR) ] = new JLabel( "Bean",new ImageIcon(getClass().getResource("gui/bean.gif")), SwingConstants.LEFT );
        listData[ antitau.get(JarType.LIB_JAR) ] = new JLabel( "Library",new ImageIcon(getClass().getResource("gui/lib.gif")), SwingConstants.LEFT );

        for( JLabel l : listData )  l.setOpaque(true);
        jList1.setListData( listData );

        jPanel7.setEnabled( false );

        wizard1.addWizardPanel( m_wPanel0 = new WizardPanel1() );
        wizard1.addWizardPanel( m_wPanel1 = new WizardPanel2() );
        wizard1.addWizardPanel( m_wPanel2 = new WizardPanel3() );
        wizard1.addWizardPanel( m_wPanel3 = new WizardPanel4() );

        FileDirectoryFilter dfilter = new FileDirectoryFilter("(Directories)");

        m_fc1 = new JFileChooser( new File(".") );
        m_fc1.setFileFilter( dfilter );
        m_fc1.setFileSelectionMode( JFileChooser.DIRECTORIES_ONLY );
        m_fc2 = new JFileChooser( new File(".") );
        m_fc2.setFileFilter( new FileExtensionFilter(".class","Java Class (*.class)") );
        m_fc3 = new JFileChooser( new File(".") );
        m_fc3.setDialogType( JFileChooser.SAVE_DIALOG );
        m_fc3.setFileFilter( new FileExtensionFilter(".jar","Java JAR (*.jar)") );
        m_fc4 = new JFileChooser( new File(".") );
        //        m_fc4.setFileFilter( new FileExtensionFilter(".*","Keystore files (*.*)") );

        ((Graphics2D)(jLabel2.getGraphics())).setRenderingHint( RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON );
        ((Graphics2D)(jLabel2.getGraphics())).setRenderingHint( RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON );

        advancedDialog.getRootPane().registerKeyboardAction(
        new ActionListener() {
            public void actionPerformed(ActionEvent actionEvent) { advancedDialog.setVisible(false); }
        },
        KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_IN_FOCUSED_WINDOW
        );

        signDialog.getRootPane().registerKeyboardAction(
        new ActionListener() {
            public void actionPerformed(ActionEvent actionEvent) { signDialog.setVisible(false); }
        },
        KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_IN_FOCUSED_WINDOW
        );

        
        // --- Internationalization ---

        wizard1.setNextText( ResourceBundle.getBundle("jarwizard_res").getString("IDS_NEXT") );
        wizard1.setBackText( ResourceBundle.getBundle("jarwizard_res").getString("IDS_BACK") );
        wizard1.setFinishText( ResourceBundle.getBundle("jarwizard_res").getString("IDS_FINISH") );

        m_fc1.setDialogTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_BASE_DIR") );
        m_fc2.setDialogTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_MAIN_CLASS") );
        m_fc3.setDialogTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_JAR_FILE") );
        m_fc4.setDialogTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_KEY_STORE_LABEL") );
        dfilter.setDescription( ResourceBundle.getBundle("jarwizard_res").getString("IDS_DIRECTORIES") );

        signDialog.setTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_SIGN_LABEL") );

        advancedDialog.setTitle( ResourceBundle.getBundle("jarwizard_res").getString("IDS_ADVANCED_TOOLTIP") );

        m_listHelpText = new String[ antitau.size() ];
        m_listHelpText[antitau.get(JarType.APPLIC_JAR)] = ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME_APPLICATION");
        m_listHelpText[antitau.get(JarType.CONSOLE_JAR)] = ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME_CONSOLE");
        m_listHelpText[antitau.get(JarType.BEAN_JAR)] = ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME_BEAN");
        m_listHelpText[antitau.get(JarType.LIB_JAR)] = ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME_LIB");
        m_listHelpText[antitau.get(JarType.APPLET_JAR)] = ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME_APPLET");


        // --- Load preferences ---

        Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
        pack();
        int x0 = (screenDim.width - getSize().width) / 2 , y0 = (screenDim.height - getSize().height) / 2;
        int x = x0 , y = y0;
        try
        {
            m_properties.load( new FileInputStream(System.getProperty("user.home") + "/JarWizard.ini") );
            x = Integer.parseInt( m_properties.getProperty("WINDOW_X") );
            y = Integer.parseInt( m_properties.getProperty("WINDOW_Y") );
            int i = Integer.parseInt( m_properties.getProperty("JAR_TYPE") );
            if( i >= 0  &&  i < listData.length /*jList1.getMaxSelectionIndex()*/ )  jList1.setSelectedIndex( i );
            setDirText( m_properties.getProperty("DIRECTORY") );
            setClassText( m_properties.getProperty("MAIN_CLASS") );
            setJarText( m_properties.getProperty("JAR_FILE") );
            setOtherText(  m_properties.getProperty("OTHER_FILES") );
            setClasspathText(  m_properties.getProperty("CLASS_PATH") );
            m_includeJpeg = Boolean.valueOf( m_properties.getProperty("INCLUDE_JPEG") ).booleanValue();
            m_includeGif = Boolean.valueOf( m_properties.getProperty("INCLUDE_GIF") ).booleanValue();
            m_includeAu = Boolean.valueOf( m_properties.getProperty("INCLUDE_AU") ).booleanValue();
            m_includeProp = Boolean.valueOf( m_properties.getProperty("INCLUDE_PROP") ).booleanValue();
            m_includeClass = Boolean.valueOf( m_properties.getProperty("INCLUDE_CLASS") ).booleanValue();
            m_includeTxt = Boolean.valueOf( m_properties.getProperty("INCLUDE_TXT") ).booleanValue();
            m_includeOther = Boolean.valueOf( m_properties.getProperty("INCLUDE_OTHER") ).booleanValue();
            setKeyStoreText(  m_properties.getProperty("KEY_STORE") );
            setPasswordText(  m_properties.getProperty("KEY_PASSWORD") );
            setAliasText(  m_properties.getProperty("KEY_ALIAS") );
            m_zipLevel = Integer.parseInt( m_properties.getProperty("ZIP_LEVEL") );
        }
        catch( IOException e )  { /* do nothing */ }
        catch( NumberFormatException e )  { /* do nothing. */ }

        setLocation( x, y );
    }

    /** Wizard page 1: project type selection */
    private class WizardPanel1 extends WizardPanel
    {
        public WizardPanel1()
        {
            super( welcomePanel );
            jList1.addListSelectionListener( wizard1 /*getWizard()*/ );
            jList1.addMouseListener( new java.awt.event.MouseAdapter()
            {
                public void mouseClicked(java.awt.event.MouseEvent evt)
                {
                    if( evt.getClickCount() == 2 )  getWizard().doMoveNext();
                }
            }
            );
        }
        public boolean canMoveNext()        // override
        {
            return ( ! jList1.isSelectionEmpty() );
        }
        public void showPanel()             // override
        {
            jList1.requestFocus();
        }
    }

    /** Wizard page 2: directory & mainclass */
    private class WizardPanel2 extends WizardPanel
    {
        public WizardPanel2()
        {
            super( mainClassPanel );
            classText.addKeyListener( wizard1 /*getWizard()*/ );
            dirText.addKeyListener( wizard1 /*getWizard()*/ );
            classText.getDocument().addDocumentListener( wizard1 );
            dirText.getDocument().addDocumentListener( wizard1 );
        }
        public boolean canMoveNext()        // override
        {
            return ( ! dirText.getText().trim().equals("")  &&  (jList1.getSelectedIndex()==antitau.get(JarType.LIB_JAR) || jList1.getSelectedIndex()==antitau.get(JarType.APPLET_JAR) || classText.getText().trim().endsWith(".class")) );
        }
        public void showPanel()             // override
        {
            dirText.setToolTipText( adjustHTMLString(dirText.getToolTipText()) );

            classText.setVisible( jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  jList1.getSelectedIndex() != antitau.get(JarType.APPLET_JAR) );
            classLabel.setVisible( jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  jList1.getSelectedIndex() != antitau.get(JarType.APPLET_JAR) );
            classButton.setVisible( jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  jList1.getSelectedIndex() != antitau.get(JarType.APPLET_JAR) );
            if( ! classText.isVisible() )
            {
                classText.setText("");      // Clear out field.
            }
            classText.selectAll();
            dirText.requestFocus();
            dirText.selectAll();
        }
        public boolean moveNext()           // override
        {
            classText.setText( classText.getText().trim() );
            dirText.setText( dirText.getText().trim() );

            if( (jList1.getSelectedIndex()!=antitau.get(JarType.LIB_JAR) && jList1.getSelectedIndex()!=antitau.get(JarType.APPLET_JAR) && ! fileExists(classText.getText())  ||  ! fileExists(dirText.getText()) ) )
            {
                JOptionPane.showMessageDialog( this, ResourceBundle.getBundle("jarwizard_res").getString("IDS_BOTH_ERROR") /*"Please, specify both the directory and the main class"*/, "Error", JOptionPane.ERROR_MESSAGE );
                return false;               // Don't move on.
            }
            return true;
        }
    }

    /** Wizard page 3: jar file */
    private class WizardPanel3 extends WizardPanel
    {
        public WizardPanel3()
        {
            super( jarFilePanel );
            jarText.addKeyListener( wizard1 /*getWizard()*/ );
            jarText.getDocument().addDocumentListener( wizard1 /*getWizard()*/ );
        }
        public boolean canMoveNext()        // override
        {
            return ( ! jarText.getText().trim().equals("") );
        }
        public boolean moveNext()           // override
        {
            classText.setText( classText.getText().trim() );
            dirText.setText( dirText.getText().trim() );

            if( (jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR) && jList1.getSelectedIndex() != antitau.get(JarType.APPLET_JAR)  &&  classText.getText().equals(""))  ||  dirText.getText().equals("") )
            {
                JOptionPane.showMessageDialog( this, ResourceBundle.getBundle("jarwizard_res").getString("IDS_BOTH_ERROR") /*"Please, specify both the directory and the main class"*/, "Error", JOptionPane.ERROR_MESSAGE );
                return false;               // Don't move on.
            }

            if( jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  jList1.getSelectedIndex()!=antitau.get(JarType.APPLET_JAR) &&  ! classText.getText().startsWith( dirText.getText() ) )
            {
                JOptionPane.showMessageDialog( this, ResourceBundle.getBundle("jarwizard_res").getString("IDS_SUBDIR_ERROR")/*"The main class has to be located below the directory selected"*/, "Error", JOptionPane.ERROR_MESSAGE );
                return false;               // Don't move on.
            }

            if( ! m_includeClass  &&  ! m_includeAu  &&  ! m_includeJpeg  &&  ! m_includeGif  &&  ! m_includeAu  &&  ! m_includeTxt  &&  ! m_includeProp  && ! m_includeOther ) {
                JOptionPane.showMessageDialog( this, ResourceBundle.getBundle("jarwizard_res").getString("IDS_NONE_INCLUDED_ERROR")/*"No files included"*/, "Error", JOptionPane.ERROR_MESSAGE );
                return false;               // Don't move on.
            }
            if( jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  ! m_includeClass ) {
                JOptionPane.showMessageDialog( this, ResourceBundle.getBundle("jarwizard_res").getString("IDS_NO_CLASSES_ERROR")/*"No files included"*/, "Error", JOptionPane.ERROR_MESSAGE );
                return false;               // Don't move on.
            }

            String mainName = classText.getText();
            String dirName = dirText.getText();

            if( jList1.getSelectedIndex() == antitau.get(JarType.CONSOLE_JAR) )
            {
                // --- Create the JCONSOLE class file in the user's application directory ---
                if( ! extractJavaClass(dirName,"JConsole.class")  ||  ! extractJavaClass(dirName,"JConsole$ConsoleByteArrayOutputStream.class")  ||  ! extractJavaClass(dirName,"JConsole$ConsoleByteArrayInputStream.class") )
                {
                    JOptionPane.showMessageDialog( this, "Jar Creation error\n\n", "Error", JOptionPane.ERROR_MESSAGE );
                    return false;           // Don't move on.
                }
                // --- Create the MAIN.CFG file ---
                {
                    if( mainName.endsWith(".class") )
                    {
                        mainName = mainName.substring( 0, mainName.lastIndexOf(".class") ); // Remove the CLASS extension from the name.
                    }

                    if( mainName.startsWith(dirName) )
                    {
                        mainName = mainName.substring( dirName.length() + 1 );  // Remove current path from the name.
                    }

                    mainName = mainName.replace('\\','/');  // Replace MSDOS slashes with unix/mac slashes.
                    FileOutputStream outF = null;
                    try
                    {
                        outF = new FileOutputStream( dirName + "/main.cfg" );
                        outF.write( (mainName+"\n").getBytes() );
                        outF.close();
                    }
                    catch( IOException e )
                    {
                        try { if(outF!=null) outF.close(); } catch(IOException e2)  { /* do nothing. */ }
                        JOptionPane.showMessageDialog( this, "Jar Creation error\n\n", "Error", JOptionPane.ERROR_MESSAGE );
                        return false;       // Don't move on.
                    }
                }
                mainName = "JConsole";      // Redirect the main class to our console class.
            }

            setCursor( Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR) );

            new JarringThread( jarringDialog, dirText.getText(), jarText.getText(), (jList1.getSelectedIndex()==antitau.get(JarType.APPLET_JAR)) ? null : mainName, (jList1.getSelectedIndex()==antitau.get(JarType.BEAN_JAR)), otherCheckBox.isSelected() ? otherTextField.getText() : null , classpathTextField.getText() ).start();
            jarringDialog.pack();
            jarringDialog.setLocationRelativeTo( this );  // jdk1.4

            jarringDialog.setVisible(true);         // Modal. Will return when thread finishes.

            boolean b;

            if( m_errorDescription == null )
            {
                jLabel111.setText( ResourceBundle.getBundle("jarwizard_res").getString("IDS_CONGRATS_1") + jarText.getText() + ResourceBundle.getBundle("jarwizard_res").getString("IDS_CONGRATS_2") );
                Toolkit.getDefaultToolkit().beep();
                b = true;                   // Move on.
            }
            else
            {
                JOptionPane.showMessageDialog( this, "Jar Creation error\n\n" + m_errorDescription + "\n\n", "Error", JOptionPane.ERROR_MESSAGE );
                b = false;                  // Don't move on.
            }
            setCursor( Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR) );
            return b;
        }
        public void showPanel()             // override
        {
            jarText.setToolTipText( adjustHTMLString(jarText.getToolTipText()) );
            if( jarText.getText().trim().equals("")  &&  jList1.getSelectedIndex() != antitau.get(JarType.LIB_JAR)  &&  jList1.getSelectedIndex() != antitau.get(JarType.APPLET_JAR) )
            {
                // By default, suggest a jar name similar to the main class name, if available.
                String temp = classText.getText().trim();
                temp = temp.substring( 0, temp.length() - 6 );  // Remove the CLASS extension from the name.
                temp = temp.replace( '\\', '/' );               // Replace MSDOS slashes with unix/mac slashes.
                int pos1 = temp.lastIndexOf('/');
                if( pos1 >= 0 )
                {
                    temp = temp.substring(pos1+1);              // Remove the path from the name.
                }
                String dirName = dirText.getText().trim();
                if( dirName.length() > 0  &&  dirName.charAt( dirName.length() - 1 ) != '/'  &&  dirName.charAt( dirName.length() - 1 ) != '\\' )
                {
                    temp = File.separator + temp;               // Add file separator just before the filename, if not present.
                }
                jarText.setText( dirName + temp + ".jar" );
            }
            jarText.requestFocus();
            jarText.selectAll();
        }
    }

    /** Wizar page 4: final page */
    private class WizardPanel4 extends WizardPanel
    {
        public WizardPanel4()
        {
            super( finishPanel );
        }
        public boolean canMoveBack()        // override
        {
            return false;
        }
        public boolean moveNext()           // override
        {
            exitJarWizard();                // Finished.
            return true;
        }
    }

    private class JarringThread extends Thread
    {
        JarringThread( JDialog dialog, String dirName, String jarName, String className, boolean isBean, String otherText, String classpathText )
        {
            m_dirName = dirName;
            m_jarName = jarName;
            m_className = className;
            m_dialog = dialog;
            m_isBean = isBean;
            m_otherText = otherText;
            m_jarsClassPathText = classpathText;
        }

        public void run()
        {
            Thread.currentThread().setPriority( MIN_PRIORITY );    // Try to make the GUI refresh better.
            while( ! m_dialog.isShowing() )  { Thread.currentThread().yield(); }
            m_errorDescription = createJar( m_dirName, m_jarName, m_className, m_isBean, m_otherText, m_jarsClassPathText, m_zipLevel );
            m_dialog.setVisible(false);
        }

        String  m_dirName, m_jarName, m_className, m_otherText, m_jarsClassPathText;
        JDialog m_dialog;
        boolean m_isBean;
    }

    /** Exit the Application */
    private void exitJarWizard()
    {
        try
        {
            // --- Save user preferences ---
            m_properties.put( "WINDOW_X", "" + getLocation().x );  m_properties.put( "WINDOW_Y", "" + getLocation().y );
            if( ! jList1.isSelectionEmpty() )  { m_properties.put( "JAR_TYPE", "" + jList1.getSelectedIndex() ); }
            if( dirText.getText().trim().length() > 0 )  { m_properties.put( "DIRECTORY", dirText.getText().trim() ); }
            if( classText.getText().trim().length() > 0)  { m_properties.put( "MAIN_CLASS", classText.getText().trim() ); }
            if( jarText.getText().trim().length() > 0 )  { m_properties.put( "JAR_FILE", jarText.getText().trim() ); }
            if( otherTextField.getText().trim().length() > 0 )  { m_properties.put( "OTHER_FILES", otherTextField.getText().trim() ); }
            if( classpathTextField.getText().trim().length() > 0 )  { m_properties.put( "CLASS_PATH", classpathTextField.getText().trim() ); }
            m_properties.put( "INCLUDE_JPEG", "" + m_includeJpeg );
            m_properties.put( "INCLUDE_GIF", "" + m_includeGif );
            m_properties.put( "INCLUDE_AU", "" + m_includeAu );
            m_properties.put( "INCLUDE_PROP", "" + m_includeProp );
            m_properties.put( "INCLUDE_CLASS", "" + m_includeClass );
            m_properties.put( "INCLUDE_TXT", "" + m_includeTxt );
            m_properties.put( "INCLUDE_OTHER", "" + m_includeOther );
            m_properties.put( "ZIP_LEVEL", "" + m_zipLevel );
            if( keyStoreTextField.getText().trim().length() > 0 )  { m_properties.put( "KEY_STORE", keyStoreTextField.getText().trim() ); }
            if( aliasTextField.getText().trim().length() > 0 )  { m_properties.put( "KEY_ALIAS", aliasTextField.getText().trim() ); }
            if( passwordTextField.getPassword().length > 0 )  { m_properties.put( "KEY_PASSWORD", new String(passwordTextField.getPassword()) ); }
            FileOutputStream outF = new FileOutputStream( System.getProperty("user.home") + "/JarWizard.ini" );
            m_properties.store( outF, "JarWizard Preferences" );  outF.close();
        }
        catch( Exception e )  { /* do nothing */ }
        dispose();  // For JSH support.
        System.exit( 0 );
    }

    private String adjustHTMLString( String s )
    {
        int pos = -1;
        do
        {
            pos = s.indexOf( "<img src=", pos + 1 );
            if( pos >= 0 )
            {
                int pos2 = s.indexOf( ">", pos );
                URL url = JarWizard.class.getResource( s.substring(pos+9,pos2) );   // JAR reference.
                if( url != null  &&  ! s.substring(pos+9,pos2).equals(url.toString()) )
                {
                    s = s.substring( 0, pos ) + "<img src=" + url.toString() + s.substring(pos2);
                }
            }
        } while( pos >= 0 );
        return s;
    }


    private boolean extractJavaClass( String dirName, String className )
    {
        FileOutputStream outF = null;
        boolean b = false;
        try
        {
            outF = new FileOutputStream( dirName + "/" + className );
            InputStream is1 = getClass().getResourceAsStream( className );  // Read bytecodes from wizard's own JAR file!!!
            byte buf[] = new byte[1000];
            int len;
            while( (len = is1.read(buf,0,buf.length)) != -1 )
            {
                outF.write(buf,0,len);
            }
            is1.close();
            b = true;       // Success.
        }
        catch( Exception e )  { /* do nothing. */ }
        finally
        {
            try { if(outF!=null) outF.close(); } catch(IOException e2)  { }
        }
        return b;
    }


    private String createJar( String dirText, String jarText, String classText, boolean isBean, String otherText, String classpathText, int zipLevel )
    {
        try
        {
            JarCreator jc = new JarCreator();
            if( m_includeClass ) jc.addExtension( "class" );
            if( m_includeGif ) jc.addExtension( "gif" );
            if( m_includeJpeg )  { jc.addExtension( "jpeg" ); jc.addExtension( "jpg" ); }
            if( m_includeAu ) jc.addExtension( "au" );
            if( m_includeProp ) jc.addExtension( "properties" );
            if( m_includeTxt ) jc.addExtension( "txt" );
            if( m_includeOther ) jc.addExtension( otherText );
            if( jList1.getSelectedIndex() == antitau.get(JarType.CONSOLE_JAR) )  jc.addFile( "main.cfg" );

            m_cmdTxt = jc.createJar( dirText, jarText, classText, isBean, classpathText, zipLevel );
        }
        catch( JarCreator.JarCreatorException e )
        {
            return e.getMessage();  // Report error description.
        }
        return null;                // Everything was OK.
    }

    private void setDirText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("")  &&  ! s.equals(dirText.getText()) )
            {
                dirText.setText( s );
                dirText.selectAll();
                m_fc1.setCurrentDirectory( new File(s) );
                m_fc2.setCurrentDirectory( m_fc1.getCurrentDirectory() );
                //            m_fc2.setSelectedFile( new File(classText.getText()) );   // Will default to current directory if Path is invalid.
                m_fc3.setCurrentDirectory( m_fc1.getCurrentDirectory() );
                setClassText("");
                setJarText(""); // Clear JAR filename too, to force a new manual selection.
            }
        }
    }

    private void setClassText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            classText.setText( s );
            classText.selectAll();
            if( ! s.equals("") )
            {
                m_fc2.setSelectedFile( new File(s) );   // Will default to current directory if Path is invalid.
            }
        }
    }

    private void setJarText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            jarText.setText( s );
            jarText.selectAll();
            if( ! s.equals("") )
            {
                m_fc3.setSelectedFile( new File(s) );   // Will default to current directory if Path is invalid.
            }
        }
    }

    private void setOtherText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("") )
            {
                otherTextField.setText( s );
                otherTextField.selectAll();
                m_otherText = s;
            }
        }
    }

    private void setClasspathText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("") )
            {
                classpathTextField.setText( s );
                classpathTextField.selectAll();
                m_jarsClassPathText = s;
            }
        }
    }

    private void setKeyStoreText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("") )
            {
                keyStoreTextField.setText( s );
                keyStoreTextField.selectAll();
                m_keyStoreText = keyStoreTextField.getText();
                m_fc4.setCurrentDirectory( new File(s) );
                m_fc4.setCurrentDirectory( m_fc4.getCurrentDirectory() );
                //            m_fc4.setSelectedFile( new File(keyStoreText.getText()) );   // Will default to current directory if Path is invalid.
                m_fc4.setCurrentDirectory( m_fc4.getCurrentDirectory() );
            }
        }
    }

    private void setPasswordText( String s )
    {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("") )
            {
                passwordTextField.setText( s );
                passwordTextField.selectAll();
                m_passwordText = new String( passwordTextField.getPassword() );
            }
        }
    }

   private void setAliasText( String s )
   {
        if( s != null )
        {
            s = s.trim();
            if( ! s.equals("") )
            {
                aliasTextField.setText( s );
                aliasTextField.selectAll();
                m_aliasText = aliasTextField.getText();
            }
        }
    }

   private boolean fileExists( String fname )
   {
       File f = new File( fname );
       return( f.exists() );
   }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        welcomePanel = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        jPanel8 = new javax.swing.JPanel();
        jSplitPane1 = new javax.swing.JSplitPane();
        jScrollPane2 = new javax.swing.JScrollPane();
        jList1 = new org.chir.swing.ComponentList();
        jPanel7 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        jLabel4 = new javax.swing.JLabel();
        mainClassPanel = new javax.swing.JPanel();
        jPanel5 = new javax.swing.JPanel();
        classText = new javax.swing.JTextField();
        classButton = new javax.swing.JButton();
        dirText = new javax.swing.JTextField();
        dirButton = new javax.swing.JButton();
        classLabel = new javax.swing.JLabel();
        dirLabel = new javax.swing.JLabel();
        jLabel11 = new javax.swing.JLabel();
        jarFilePanel = new javax.swing.JPanel();
        jLabel112 = new javax.swing.JLabel();
        jPanel2 = new javax.swing.JPanel();
        jPanel51 = new javax.swing.JPanel();
        jarText = new javax.swing.JTextField();
        classButton1 = new javax.swing.JButton();
        jarLabel = new javax.swing.JLabel();
        advButton = new javax.swing.JButton();
        finishPanel = new javax.swing.JPanel();
        jLabel111 = new javax.swing.JLabel();
        signButton = new javax.swing.JButton();
        pasteButton = new javax.swing.JButton();
        jarringDialog = new javax.swing.JDialog();
        jLabel3 = new javax.swing.JLabel();
        advancedDialog = new javax.swing.JDialog();
        jPanel4 = new javax.swing.JPanel();
        jpegCheckBox = new javax.swing.JCheckBox();
        gifCheckBox = new javax.swing.JCheckBox();
        auCheckBox = new javax.swing.JCheckBox();
        propCheckBox = new javax.swing.JCheckBox();
        clsCheckBox = new javax.swing.JCheckBox();
        txtCheckBox = new javax.swing.JCheckBox();
        otherCheckBox = new javax.swing.JCheckBox();
        otherTextField = new javax.swing.JTextField();
        okButton1 = new javax.swing.JButton();
        cancelButton1 = new javax.swing.JButton();
        jPanel10 = new javax.swing.JPanel();
        classpathTextField = new javax.swing.JTextField();
        jPanel11 = new javax.swing.JPanel();
        zipLevelSlider = new javax.swing.JSlider();
        jLabel1 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        signDialog = new javax.swing.JDialog();
        jPanel41 = new javax.swing.JPanel();
        keyStoreLabel = new javax.swing.JLabel();
        keyStoreTextField = new javax.swing.JTextField();
        keyStoreButton = new javax.swing.JButton();
        aliasTextField = new javax.swing.JTextField();
        aliasLabel = new javax.swing.JLabel();
        passwordLabel1 = new javax.swing.JLabel();
        passwordTextField = new javax.swing.JPasswordField();
        okButton11 = new javax.swing.JButton();
        cancelButton11 = new javax.swing.JButton();
        topLabel = new javax.swing.JLabel();
        wizard1 = new org.chir.swing.Wizard();

        welcomePanel.setLayout(new java.awt.BorderLayout(0, 10));

        welcomePanel.setPreferredSize(new java.awt.Dimension(492, 361));
        jLabel2.setFont(new java.awt.Font("Times New Roman", 0, 12));
        jLabel2.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_WELCOME"));
        welcomePanel.add(jLabel2, java.awt.BorderLayout.NORTH);

        jPanel8.setLayout(new java.awt.BorderLayout());

        jPanel8.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_PROJECT_TYPE")));
        jSplitPane1.setBorder(null);
        jSplitPane1.setDividerSize(8);
        jScrollPane2.setPreferredSize(new java.awt.Dimension(185, 155));
        jList1.setBorder(new javax.swing.border.BevelBorder(javax.swing.border.BevelBorder.LOWERED));
        jList1.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        jList1.setMaximumSize(null);
        jList1.setMinimumSize(new java.awt.Dimension(50, 50));
        jList1.setPreferredSize(null);
        jList1.setVisibleRowCount(4);
        jList1.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                jList1ValueChanged(evt);
            }
        });

        jScrollPane2.setViewportView(jList1);

        jSplitPane1.setLeftComponent(jScrollPane2);

        jPanel7.setLayout(new java.awt.BorderLayout());

        jPanel7.setBorder(new javax.swing.border.TitledBorder(null, java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_PROJECT_DESCRIPTION"), javax.swing.border.TitledBorder.LEFT, javax.swing.border.TitledBorder.DEFAULT_POSITION));
        jPanel7.setPreferredSize(new java.awt.Dimension(250, 155));
        jLabel4.setFont(new java.awt.Font("Times New Roman", 0, 12));
        jLabel4.setVerticalAlignment(javax.swing.SwingConstants.TOP);
        jLabel4.setPreferredSize(new java.awt.Dimension(230, 300));
        jScrollPane1.setViewportView(jLabel4);

        jPanel7.add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jSplitPane1.setRightComponent(jPanel7);

        jPanel8.add(jSplitPane1, java.awt.BorderLayout.CENTER);

        welcomePanel.add(jPanel8, java.awt.BorderLayout.CENTER);

        mainClassPanel.setLayout(new java.awt.BorderLayout());

        jPanel5.setLayout(new java.awt.GridBagLayout());

        jPanel5.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_FILE_LOCATIONS")));
        jPanel5.setMinimumSize(new java.awt.Dimension(500, 100));
        jPanel5.setPreferredSize(new java.awt.Dimension(500, 100));
        classText.setFont(new java.awt.Font("Arial", 0, 12));
        classText.setHorizontalAlignment(javax.swing.JTextField.LEFT);
        classText.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_MAIN_CLASS_TOOLTIP"));
        classText.setMinimumSize(new java.awt.Dimension(240, 23));
        classText.setNextFocusableComponent(dirText);
        classText.setPreferredSize(new java.awt.Dimension(240, 23));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 2, 4, 0);
        jPanel5.add(classText, gridBagConstraints);

        classButton.setFont(new java.awt.Font("Arial", 0, 10));
        classButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/browse.gif")));
        classButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BROWSE"));
        classButton.setMaximumSize(new java.awt.Dimension(30, 25));
        classButton.setMinimumSize(new java.awt.Dimension(30, 25));
        classButton.setPreferredSize(new java.awt.Dimension(30, 25));
        classButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                classButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 0);
        jPanel5.add(classButton, gridBagConstraints);

        dirText.setFont(new java.awt.Font("Arial", 0, 12));
        dirText.setHorizontalAlignment(javax.swing.JTextField.LEFT);
        dirText.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BASE_DIR_TOOLTIP"));
        dirText.setMinimumSize(new java.awt.Dimension(240, 23));
        dirText.setNextFocusableComponent(classText);
        dirText.setPreferredSize(new java.awt.Dimension(240, 23));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 2, 4, 0);
        jPanel5.add(dirText, gridBagConstraints);

        dirButton.setFont(new java.awt.Font("Arial", 0, 10));
        dirButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/browse.gif")));
        dirButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BROWSE"));
        dirButton.setMaximumSize(new java.awt.Dimension(30, 25));
        dirButton.setMinimumSize(new java.awt.Dimension(30, 25));
        dirButton.setPreferredSize(new java.awt.Dimension(30, 25));
        dirButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                dirButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 0);
        jPanel5.add(dirButton, gridBagConstraints);

        classLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        classLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/main.gif")));
        classLabel.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_MAIN_CLASS"));
        classLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        classLabel.setMaximumSize(new java.awt.Dimension(890, 250));
        classLabel.setMinimumSize(new java.awt.Dimension(100, 25));
        classLabel.setPreferredSize(new java.awt.Dimension(130, 25));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel5.add(classLabel, gridBagConstraints);

        dirLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        dirLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/open.gif")));
        dirLabel.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BASE_DIR"));
        dirLabel.setMaximumSize(new java.awt.Dimension(800, 250));
        dirLabel.setMinimumSize(new java.awt.Dimension(100, 25));
        dirLabel.setPreferredSize(new java.awt.Dimension(130, 25));
        dirLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel5.add(dirLabel, gridBagConstraints);

        mainClassPanel.add(jPanel5, java.awt.BorderLayout.CENTER);

        jLabel11.setFont(new java.awt.Font("Times New Roman", 0, 12));
        jLabel11.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        jLabel11.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_FILL_IN_1"));
        jLabel11.setIconTextGap(10);
        jLabel11.setMaximumSize(new java.awt.Dimension(500, 500));
        jLabel11.setMinimumSize(new java.awt.Dimension(480, 150));
        jLabel11.setPreferredSize(new java.awt.Dimension(480, 150));
        jLabel11.setRequestFocusEnabled(false);
        jLabel11.setVerticalTextPosition(javax.swing.SwingConstants.TOP);
        mainClassPanel.add(jLabel11, java.awt.BorderLayout.NORTH);

        jarFilePanel.setLayout(new java.awt.BorderLayout());

        jLabel112.setFont(new java.awt.Font("Times New Roman", 0, 12));
        jLabel112.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        jLabel112.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_FILL_IN_2"));
        jLabel112.setIconTextGap(10);
        jLabel112.setMinimumSize(new java.awt.Dimension(500, 120));
        jLabel112.setPreferredSize(new java.awt.Dimension(500, 120));
        jLabel112.setRequestFocusEnabled(false);
        jLabel112.setVerticalTextPosition(javax.swing.SwingConstants.TOP);
        jarFilePanel.add(jLabel112, java.awt.BorderLayout.NORTH);

        jPanel2.setLayout(new java.awt.GridBagLayout());

        jPanel2.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_DESTINATION_FILE")));
        jPanel2.setAlignmentX(0.0F);
        jPanel2.setAlignmentY(0.0F);
        jPanel2.setMinimumSize(new java.awt.Dimension(400, 250));
        jPanel2.setPreferredSize(new java.awt.Dimension(480, 250));
        jPanel51.setLayout(new java.awt.GridBagLayout());

        jPanel51.setMinimumSize(new java.awt.Dimension(450, 100));
        jPanel51.setPreferredSize(new java.awt.Dimension(470, 100));
        jarText.setFont(new java.awt.Font("Arial", 0, 12));
        jarText.setHorizontalAlignment(javax.swing.JTextField.LEFT);
        jarText.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_JAR_FILE_TOOLTIP"));
        jarText.setMinimumSize(new java.awt.Dimension(240, 23));
        jarText.setPreferredSize(new java.awt.Dimension(240, 23));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 2, 4, 0);
        jPanel51.add(jarText, gridBagConstraints);

        classButton1.setFont(new java.awt.Font("Arial", 0, 10));
        classButton1.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/browse.gif")));
        classButton1.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BROWSE"));
        classButton1.setMaximumSize(new java.awt.Dimension(3000, 2300));
        classButton1.setMinimumSize(new java.awt.Dimension(30, 25));
        classButton1.setPreferredSize(new java.awt.Dimension(30, 25));
        classButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                classButton1ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 0);
        jPanel51.add(classButton1, gridBagConstraints);

        jarLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        jarLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/jar.gif")));
        jarLabel.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_JAR_FILE"));
        jarLabel.setMaximumSize(new java.awt.Dimension(670, 250));
        jarLabel.setMinimumSize(new java.awt.Dimension(70, 25));
        jarLabel.setPreferredSize(new java.awt.Dimension(130, 25));
        jarLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel51.add(jarLabel, gridBagConstraints);

        advButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/advanced.gif")));
        advButton.setMnemonic('v');
        advButton.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_ADVANCED"));
        advButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_ADVANCED_TOOLTIP"));
        advButton.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        advButton.setIconTextGap(10);
        advButton.setMargin(new java.awt.Insets(2, 8, 2, 14));
        advButton.setMaximumSize(new java.awt.Dimension(1004, 23));
        advButton.setMinimumSize(new java.awt.Dimension(125, 23));
        advButton.setPreferredSize(new java.awt.Dimension(125, 23));
        advButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                advButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 0);
        jPanel51.add(advButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        jPanel2.add(jPanel51, gridBagConstraints);

        jarFilePanel.add(jPanel2, java.awt.BorderLayout.CENTER);

        finishPanel.setLayout(new java.awt.GridBagLayout());

        finishPanel.setAlignmentX(0.0F);
        finishPanel.setAlignmentY(0.0F);
        finishPanel.setMinimumSize(new java.awt.Dimension(500, 250));
        finishPanel.setPreferredSize(new java.awt.Dimension(500, 250));
        jLabel111.setFont(new java.awt.Font("Times New Roman", 0, 12));
        jLabel111.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        jLabel111.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/finish.gif")));
        jLabel111.setText("<html><br><u>Congratulations !</u><br><br>Your file<br><br>XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX<br><br> was successfully created. <br><br>Press Finish to exit.<br><br> </html>");
        jLabel111.setIconTextGap(10);
        jLabel111.setMinimumSize(new java.awt.Dimension(380, 200));
        jLabel111.setPreferredSize(new java.awt.Dimension(380, 200));
        jLabel111.setRequestFocusEnabled(false);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridheight = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weighty = 1.0;
        finishPanel.add(jLabel111, gridBagConstraints);

        signButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/check.gif")));
        signButton.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_SIGN_LABEL"));
        signButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_SIGN_TOOLTIP"));
        signButton.setMargin(new java.awt.Insets(2, 4, 2, 14));
        signButton.setMaximumSize(new java.awt.Dimension(960, 23));
        signButton.setMinimumSize(new java.awt.Dimension(100, 23));
        signButton.setPreferredSize(new java.awt.Dimension(120, 23));
        signButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                signButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 10, 0);
        finishPanel.add(signButton, gridBagConstraints);

        pasteButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/paste.gif")));
        pasteButton.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_PASTE_LABEL"));
        pasteButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_PASTE_TOOLTIP"));
        pasteButton.setMargin(new java.awt.Insets(2, 4, 2, 14));
        pasteButton.setMaximumSize(new java.awt.Dimension(960, 23));
        pasteButton.setMinimumSize(new java.awt.Dimension(100, 23));
        pasteButton.setPreferredSize(new java.awt.Dimension(120, 23));
        pasteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                pasteButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 10, 0);
        finishPanel.add(pasteButton, gridBagConstraints);

        jarringDialog.setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        jarringDialog.setTitle("Working...");
        jarringDialog.setCursor(new java.awt.Cursor(java.awt.Cursor.DEFAULT_CURSOR));
        jarringDialog.setModal(true);
        jarringDialog.setResizable(false);
        jarringDialog.setUndecorated(true);
        jLabel3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel3.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/jarring.gif")));
        jLabel3.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_WAIT"));
        jLabel3.setBorder(new javax.swing.border.BevelBorder(javax.swing.border.BevelBorder.RAISED));
        jLabel3.setMinimumSize(new java.awt.Dimension(300, 100));
        jLabel3.setPreferredSize(new java.awt.Dimension(300, 100));
        jarringDialog.getContentPane().add(jLabel3, java.awt.BorderLayout.CENTER);

        advancedDialog.getContentPane().setLayout(new java.awt.GridBagLayout());

        advancedDialog.setTitle("Advanced options");
        advancedDialog.setModal(true);
        advancedDialog.setResizable(false);
        jPanel4.setLayout(new java.awt.GridLayout(3, 2));

        jPanel4.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_INCLUDED_FILES")));
        jPanel4.setMinimumSize(new java.awt.Dimension(220, 50));
        jPanel4.setPreferredSize(new java.awt.Dimension(220, 50));
        jpegCheckBox.setText("Jpeg");
        jpegCheckBox.setMaximumSize(new java.awt.Dimension(530, 24));
        jpegCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        jpegCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(jpegCheckBox);

        gifCheckBox.setText("Gif");
        gifCheckBox.setMaximumSize(new java.awt.Dimension(400, 24));
        gifCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        gifCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(gifCheckBox);

        auCheckBox.setText("Au");
        auCheckBox.setMaximumSize(new java.awt.Dimension(400, 24));
        auCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        auCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(auCheckBox);

        propCheckBox.setText("Properties");
        propCheckBox.setMaximumSize(new java.awt.Dimension(850, 24));
        propCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        propCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(propCheckBox);

        clsCheckBox.setText("Class");
        clsCheckBox.setMaximumSize(new java.awt.Dimension(570, 24));
        clsCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        clsCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(clsCheckBox);

        txtCheckBox.setText("Txt");
        txtCheckBox.setMaximumSize(new java.awt.Dimension(430, 24));
        txtCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        txtCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        jPanel4.add(txtCheckBox);

        otherCheckBox.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_OTHERS"));
        otherCheckBox.setMaximumSize(new java.awt.Dimension(640, 240));
        otherCheckBox.setMinimumSize(new java.awt.Dimension(50, 25));
        otherCheckBox.setPreferredSize(new java.awt.Dimension(50, 25));
        otherCheckBox.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                otherCheckBoxStateChanged(evt);
            }
        });

        jPanel4.add(otherCheckBox);

        otherTextField.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_OTHERS_TOOLTIP"));
        otherTextField.setMinimumSize(new java.awt.Dimension(50, 25));
        otherTextField.setPreferredSize(new java.awt.Dimension(50, 25));
        otherTextField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                otherTextFieldActionPerformed(evt);
            }
        });

        jPanel4.add(otherTextField);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridheight = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipadx = 46;
        gridBagConstraints.ipady = 54;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        advancedDialog.getContentPane().add(jPanel4, gridBagConstraints);

        okButton1.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_OK"));
        okButton1.setMaximumSize(new java.awt.Dimension(790, 23));
        okButton1.setMinimumSize(new java.awt.Dimension(30, 23));
        okButton1.setPreferredSize(new java.awt.Dimension(30, 23));
        okButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButton1ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.ipadx = 58;
        gridBagConstraints.ipady = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        advancedDialog.getContentPane().add(okButton1, gridBagConstraints);

        cancelButton1.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_CANCEL"));
        cancelButton1.setDefaultCapable(false);
        cancelButton1.setMaximumSize(new java.awt.Dimension(1000, 23));
        cancelButton1.setMinimumSize(new java.awt.Dimension(30, 23));
        cancelButton1.setPreferredSize(new java.awt.Dimension(30, 23));
        cancelButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButton1ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.ipadx = 58;
        gridBagConstraints.ipady = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        advancedDialog.getContentPane().add(cancelButton1, gridBagConstraints);

        jPanel10.setLayout(new java.awt.BorderLayout());

        jPanel10.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_CLASSPATH_TITLE")));
        classpathTextField.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_CLASSPATH_TOOLTIP"));
        jPanel10.add(classpathTextField, java.awt.BorderLayout.CENTER);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        advancedDialog.getContentPane().add(jPanel10, gridBagConstraints);

        jPanel11.setLayout(new java.awt.BorderLayout());

        jPanel11.setBorder(new javax.swing.border.TitledBorder(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_ZIP_LEVEL")));
        zipLevelSlider.setMajorTickSpacing(1);
        zipLevelSlider.setMaximum(9);
        zipLevelSlider.setMinorTickSpacing(1);
        zipLevelSlider.setPaintTicks(true);
        zipLevelSlider.setSnapToTicks(true);
        zipLevelSlider.setValue(6);
        jPanel11.add(zipLevelSlider, java.awt.BorderLayout.CENTER);

        jLabel1.setFont(new java.awt.Font("Dialog", 0, 12));
        jLabel1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel1.setText("Min");
        jLabel1.setVerticalAlignment(javax.swing.SwingConstants.TOP);
        jLabel1.setMaximumSize(new java.awt.Dimension(50, 30));
        jLabel1.setMinimumSize(new java.awt.Dimension(50, 30));
        jLabel1.setPreferredSize(new java.awt.Dimension(50, 30));
        jLabel1.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        jPanel11.add(jLabel1, java.awt.BorderLayout.WEST);

        jLabel5.setFont(new java.awt.Font("Dialog", 0, 12));
        jLabel5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel5.setText("Max");
        jLabel5.setVerticalAlignment(javax.swing.SwingConstants.TOP);
        jLabel5.setMaximumSize(new java.awt.Dimension(50, 30));
        jLabel5.setMinimumSize(new java.awt.Dimension(50, 30));
        jLabel5.setPreferredSize(new java.awt.Dimension(50, 30));
        jLabel5.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        jPanel11.add(jLabel5, java.awt.BorderLayout.EAST);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        advancedDialog.getContentPane().add(jPanel11, gridBagConstraints);

        signDialog.getContentPane().setLayout(new java.awt.GridBagLayout());

        signDialog.setTitle("Advanced options");
        signDialog.setModal(true);
        signDialog.setResizable(false);
        jPanel41.setLayout(new java.awt.GridBagLayout());

        jPanel41.setMinimumSize(new java.awt.Dimension(300, 70));
        jPanel41.setPreferredSize(new java.awt.Dimension(325, 70));
        keyStoreLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        keyStoreLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/key.gif")));
        keyStoreLabel.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_KEY_STORE_LABEL"));
        keyStoreLabel.setMaximumSize(new java.awt.Dimension(670, 250));
        keyStoreLabel.setMinimumSize(new java.awt.Dimension(150, 25));
        keyStoreLabel.setPreferredSize(new java.awt.Dimension(150, 25));
        keyStoreLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel41.add(keyStoreLabel, gridBagConstraints);

        keyStoreTextField.setFont(new java.awt.Font("Arial", 0, 12));
        keyStoreTextField.setHorizontalAlignment(javax.swing.JTextField.LEFT);
        keyStoreTextField.setToolTipText("");
        keyStoreTextField.setMinimumSize(new java.awt.Dimension(150, 23));
        keyStoreTextField.setPreferredSize(new java.awt.Dimension(240, 23));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 2, 4, 0);
        jPanel41.add(keyStoreTextField, gridBagConstraints);

        keyStoreButton.setFont(new java.awt.Font("Arial", 0, 10));
        keyStoreButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/browse.gif")));
        keyStoreButton.setToolTipText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_BROWSE"));
        keyStoreButton.setMaximumSize(new java.awt.Dimension(3000, 2300));
        keyStoreButton.setMinimumSize(new java.awt.Dimension(30, 25));
        keyStoreButton.setPreferredSize(new java.awt.Dimension(30, 25));
        keyStoreButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                keyStoreButtonActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 0);
        jPanel41.add(keyStoreButton, gridBagConstraints);

        aliasTextField.setToolTipText("");
        aliasTextField.setMinimumSize(new java.awt.Dimension(150, 23));
        aliasTextField.setPreferredSize(new java.awt.Dimension(50, 25));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 2, 4, 0);
        jPanel41.add(aliasTextField, gridBagConstraints);

        aliasLabel.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        aliasLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/alias.gif")));
        aliasLabel.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_KEY_ALIAS_LABEL"));
        aliasLabel.setMaximumSize(new java.awt.Dimension(670, 250));
        aliasLabel.setMinimumSize(new java.awt.Dimension(150, 25));
        aliasLabel.setPreferredSize(new java.awt.Dimension(150, 25));
        aliasLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel41.add(aliasLabel, gridBagConstraints);

        passwordLabel1.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        passwordLabel1.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/empty16.gif")));
        passwordLabel1.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_KEY_PASSWORD_LABEL"));
        passwordLabel1.setMaximumSize(new java.awt.Dimension(670, 250));
        passwordLabel1.setMinimumSize(new java.awt.Dimension(150, 25));
        passwordLabel1.setPreferredSize(new java.awt.Dimension(150, 25));
        passwordLabel1.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 2);
        jPanel41.add(passwordLabel1, gridBagConstraints);

        passwordTextField.setMinimumSize(new java.awt.Dimension(150, 23));
        jPanel41.add(passwordTextField, new java.awt.GridBagConstraints());

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridheight = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipadx = 46;
        gridBagConstraints.ipady = 54;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        signDialog.getContentPane().add(jPanel41, gridBagConstraints);

        okButton11.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_OK"));
        okButton11.setMaximumSize(new java.awt.Dimension(790, 23));
        okButton11.setMinimumSize(new java.awt.Dimension(30, 23));
        okButton11.setPreferredSize(new java.awt.Dimension(30, 23));
        okButton11.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButton11ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.ipadx = 58;
        gridBagConstraints.ipady = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        signDialog.getContentPane().add(okButton11, gridBagConstraints);

        cancelButton11.setText(java.util.ResourceBundle.getBundle("jarwizard_res").getString("IDS_CANCEL"));
        cancelButton11.setDefaultCapable(false);
        cancelButton11.setMaximumSize(new java.awt.Dimension(1000, 23));
        cancelButton11.setMinimumSize(new java.awt.Dimension(30, 23));
        cancelButton11.setPreferredSize(new java.awt.Dimension(30, 23));
        cancelButton11.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButton11ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.ipadx = 58;
        gridBagConstraints.ipady = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        signDialog.getContentPane().add(cancelButton11, gridBagConstraints);

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                exitForm(evt);
            }
        });

        topLabel.setFont(new java.awt.Font("Times New Roman", 0, 12));
        topLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        topLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/gui/top.gif")));
        topLabel.setAlignmentY(0.0F);
        topLabel.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        topLabel.setRequestFocusEnabled(false);
        getContentPane().add(topLabel, java.awt.BorderLayout.NORTH);

        wizard1.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(10, 10, 10, 10)));
        wizard1.setMinimumSize(new java.awt.Dimension(500, 210));
        wizard1.setPreferredSize(new java.awt.Dimension(500, 335));
        getContentPane().add(wizard1, java.awt.BorderLayout.CENTER);

        pack();
    }
    // </editor-fold>//GEN-END:initComponents

    private void pasteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_pasteButtonActionPerformed

        try
        {
            StringSelection data = new StringSelection(m_cmdTxt);
            Clipboard clipboard = getToolkit().getSystemClipboard();
            clipboard.setContents(data, data);
            JOptionPane.showMessageDialog( null, ResourceBundle.getBundle("jarwizard_res").getString("IDS_PASTE_MSG"), "Copy", JOptionPane.INFORMATION_MESSAGE );
        }
        catch( Exception e )
        {
            JOptionPane.showMessageDialog( null, "Can't copy to clipboard.", "Error", JOptionPane.ERROR_MESSAGE );
        }
    }//GEN-LAST:event_pasteButtonActionPerformed

    private void keyStoreButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_keyStoreButtonActionPerformed
        // Add your handling code here:
        if( m_fc4.showOpenDialog( this ) == JFileChooser.APPROVE_OPTION ) {
            setKeyStoreText( m_fc4.getSelectedFile().getAbsolutePath() );
        }
        keyStoreTextField.requestFocus();
    }//GEN-LAST:event_keyStoreButtonActionPerformed

    private void cancelButton11ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelButton11ActionPerformed
        // Add your handling code here:
        signDialog.setVisible(false);
    }//GEN-LAST:event_cancelButton11ActionPerformed

    private void okButton11ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okButton11ActionPerformed
        // Add your handling code here:
        m_okPressed = true;
        signDialog.setVisible(false);
    }//GEN-LAST:event_okButton11ActionPerformed

    private void signButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_signButtonActionPerformed
        // Add your handling code here:
        signDialog.pack();
        signDialog.setLocationRelativeTo( this );  // jdk1.4

        signDialog.getRootPane().setDefaultButton( okButton11 );
        m_okPressed = false;
        keyStoreTextField.setText( m_keyStoreText );
        passwordTextField.setText( m_passwordText );
        aliasTextField.setText( m_aliasText );
        signDialog.setVisible(true);   // Modal.
        if( m_okPressed )
        {
            m_keyStoreText = keyStoreTextField.getText();
            m_passwordText = new String( passwordTextField.getPassword() );
            m_aliasText = aliasTextField.getText();

            String cmdT;
            cmdT = "jarsigner -keystore \"" + m_keyStoreText + "\" " +  " -storepass " + m_passwordText + " \"" + jarText.getText() + "\" " + m_aliasText;

            System.out.println( "\nexec |" + cmdT + "|\n" );
            setCursor( Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR) );
            try
            {
                if( ! CommandLine.ExecuteCommand( cmdT, new File("."), 2, false, true ) )
                {
                    JOptionPane.showMessageDialog(null, "Failed to sign JAR file.",  "Error", JOptionPane.ERROR_MESSAGE );
                }
                else
                {
                    JOptionPane.showMessageDialog(null, "JAR file successfully signed.",  "Sign", JOptionPane.INFORMATION_MESSAGE );
                }
            }
            catch( java.io.IOException e1 )
            {
                JOptionPane.showMessageDialog(null, ResourceBundle.getBundle("jarwizard_res").getString("IDS_JARSIGNER_NOT_FOUND_ERROR"), "Error", JOptionPane.ERROR_MESSAGE );
            }
            setCursor( Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR) );
        }
    }//GEN-LAST:event_signButtonActionPerformed

    private void otherTextFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_otherTextFieldActionPerformed
        // Add your handling code here:
    }//GEN-LAST:event_otherTextFieldActionPerformed

    private void otherCheckBoxStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_otherCheckBoxStateChanged
        // Add your handling code here:
        otherTextField.setEnabled( otherCheckBox.isSelected() );
    }//GEN-LAST:event_otherCheckBoxStateChanged

private void cancelButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelButton1ActionPerformed
    // Add your handling code here:
    advancedDialog.setVisible(false);
}//GEN-LAST:event_cancelButton1ActionPerformed

private void okButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okButton1ActionPerformed
    // Add your handling code here:
    m_okPressed = true;
    advancedDialog.setVisible(false);
}//GEN-LAST:event_okButton1ActionPerformed
/** Show Advanced Options modal requester. */
private void advButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_advButtonActionPerformed
    // Add your handling code here:
    advancedDialog.pack();
    advancedDialog.setLocationRelativeTo( this );  // jdk1.4

    advancedDialog.getRootPane().setDefaultButton( okButton1 );
    m_okPressed = false;
    jpegCheckBox.setSelected( m_includeJpeg );
    gifCheckBox.setSelected( m_includeGif );
    auCheckBox.setSelected( m_includeAu );
    propCheckBox.setSelected( m_includeProp );
    clsCheckBox.setSelected( m_includeClass );
    txtCheckBox.setSelected( m_includeTxt );
    otherCheckBox.setSelected( m_includeOther );
    otherTextField.setEnabled( m_includeOther );  otherTextField.setText( m_otherText );
    classpathTextField.setText( m_jarsClassPathText );
    zipLevelSlider.setValue( m_zipLevel );
    classpathTextField.setToolTipText( adjustHTMLString(classpathTextField.getToolTipText()) );
    advancedDialog.setVisible(true);   // Modal.
    if( m_okPressed )
    {
        m_includeJpeg = jpegCheckBox.isSelected();
        m_includeGif = gifCheckBox.isSelected();
        m_includeAu = auCheckBox.isSelected();
        m_includeProp = propCheckBox.isSelected();
        m_includeClass = clsCheckBox.isSelected();
        m_includeTxt = txtCheckBox.isSelected();
        m_includeOther = otherCheckBox.isSelected();
        m_otherText = otherTextField.getText();
        m_jarsClassPathText = classpathTextField.getText();
        m_zipLevel = zipLevelSlider.getValue();
    }
}//GEN-LAST:event_advButtonActionPerformed

    private void jList1ValueChanged(javax.swing.event.ListSelectionEvent evt)//GEN-FIRST:event_jList1ValueChanged
    {//GEN-HEADEREND:event_jList1ValueChanged
        // Add your handling code here:
        jPanel7.setEnabled(true);
        jLabel4.setText( m_listHelpText[jList1.getSelectedIndex()] );   // Show help related to the selected item.
        jLabel4.setText( adjustHTMLString(jLabel4.getText()) );
        jLabel4.revalidate();   // Adjust parent ScrollPane.
    }//GEN-LAST:event_jList1ValueChanged

    private void classButton1ActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_classButton1ActionPerformed
    {//GEN-HEADEREND:event_classButton1ActionPerformed
        // Add your handling code here:
        if( m_fc3.showOpenDialog(this) == JFileChooser.APPROVE_OPTION ) {
            setJarText( m_fc3.getSelectedFile().getPath() );
        }
        //        updateNextButton2();
        jarText.requestFocus();
    }//GEN-LAST:event_classButton1ActionPerformed

    private void classButtonActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_classButtonActionPerformed
    {//GEN-HEADEREND:event_classButtonActionPerformed
        // Add your handling code here:
        if( m_fc2.showOpenDialog(this) == JFileChooser.APPROVE_OPTION ) {
            setClassText( m_fc2.getSelectedFile().getPath() );
        }
        //        updateNextButton1();
        classText.requestFocus();
    }//GEN-LAST:event_classButtonActionPerformed

    private void dirButtonActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_dirButtonActionPerformed
    {//GEN-HEADEREND:event_dirButtonActionPerformed
        // Add your handling code here:
        if( m_fc1.showOpenDialog( this ) == JFileChooser.APPROVE_OPTION ) {
            setDirText( m_fc1.getSelectedFile().getAbsolutePath() );
            //            m_fc2.setCurrentDirectory( m_fc1.getSelectedFile() );
            //            m_fc3.setCurrentDirectory( m_fc1.getSelectedFile() );
        }
        //        updateNextButton1();
        dirText.requestFocus();
    }//GEN-LAST:event_dirButtonActionPerformed

    /** Exit the Application */
    private void exitForm(java.awt.event.WindowEvent evt)
    {//GEN-FIRST:event_exitForm
        exitJarWizard();
    }//GEN-LAST:event_exitForm

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton advButton;
    private javax.swing.JDialog advancedDialog;
    private javax.swing.JLabel aliasLabel;
    private javax.swing.JTextField aliasTextField;
    private javax.swing.JCheckBox auCheckBox;
    private javax.swing.JButton cancelButton1;
    private javax.swing.JButton cancelButton11;
    private javax.swing.JButton classButton;
    private javax.swing.JButton classButton1;
    private javax.swing.JLabel classLabel;
    private javax.swing.JTextField classText;
    private javax.swing.JTextField classpathTextField;
    private javax.swing.JCheckBox clsCheckBox;
    private javax.swing.JButton dirButton;
    private javax.swing.JLabel dirLabel;
    private javax.swing.JTextField dirText;
    private javax.swing.JPanel finishPanel;
    private javax.swing.JCheckBox gifCheckBox;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel111;
    private javax.swing.JLabel jLabel112;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private org.chir.swing.ComponentList jList1;
    private javax.swing.JPanel jPanel10;
    private javax.swing.JPanel jPanel11;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel41;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanel51;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JPanel jPanel8;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JPanel jarFilePanel;
    private javax.swing.JLabel jarLabel;
    private javax.swing.JTextField jarText;
    private javax.swing.JDialog jarringDialog;
    private javax.swing.JCheckBox jpegCheckBox;
    private javax.swing.JButton keyStoreButton;
    private javax.swing.JLabel keyStoreLabel;
    private javax.swing.JTextField keyStoreTextField;
    private javax.swing.JPanel mainClassPanel;
    private javax.swing.JButton okButton1;
    private javax.swing.JButton okButton11;
    private javax.swing.JCheckBox otherCheckBox;
    private javax.swing.JTextField otherTextField;
    private javax.swing.JLabel passwordLabel1;
    private javax.swing.JPasswordField passwordTextField;
    private javax.swing.JButton pasteButton;
    private javax.swing.JCheckBox propCheckBox;
    private javax.swing.JButton signButton;
    private javax.swing.JDialog signDialog;
    private javax.swing.JLabel topLabel;
    private javax.swing.JCheckBox txtCheckBox;
    private javax.swing.JPanel welcomePanel;
    private org.chir.swing.Wizard wizard1;
    private javax.swing.JSlider zipLevelSlider;
    // End of variables declaration//GEN-END:variables

    private static final String VERSION_T = "2.50 RC1";
    private enum JarType
    {
        APPLET_JAR, APPLIC_JAR, CONSOLE_JAR, BEAN_JAR, LIB_JAR;
/*
        int value()
        {
            switch(this)
            {
                case APPLET_JAR:    return 0;
                case APPLIC_JAR:    return 1;
                case CONSOLE_JAR:   return 2;
                case BEAN_JAR:      return 3;
                default:            return 4;
            }
        }
*/
    };
    private WizardPanel1        m_wPanel0;
    private WizardPanel2        m_wPanel1;
    private WizardPanel3        m_wPanel2;
    private WizardPanel4        m_wPanel3;
    private JFileChooser        m_fc1, m_fc2, m_fc3, m_fc4;
    private Properties          m_properties = new Properties();    // Used by INI file.
    private String              m_errorDescription;                 // Passed "by reference" to the worker thread.
    private String[]            m_listHelpText;                     // Project type descriptions.
    private boolean             m_okPressed;                        // Used by modal dialogs.
    private boolean             m_includeJpeg = true, m_includeGif = true, m_includeAu = true, m_includeProp = true, m_includeClass = true, m_includeTxt = true, m_includeOther = false;
    private String              m_otherText = "png";                // Custom extension to include.
    private String              m_jarsClassPathText = "";           // Custom additional JARs, if needed.
    private String              m_keyStoreText = "";                // Signing keystore.
    private String              m_passwordText = "";                // Signing password.
    private String              m_aliasText = "";                   // Signing user.
    private int                 m_zipLevel = 6;                     // Zip compression level.
    private String              m_cmdTxt = "";                      // Last JAR command successfully executed.
    private Hashtable<Integer,JarType> tau = new Hashtable<Integer,JarType>();
    private Hashtable<JarType,Integer> antitau = new Hashtable<JarType,Integer>();
}
